aboutsummaryrefslogtreecommitdiffstats
path: root/jenkins/create_jobs.groovy
diff options
context:
space:
mode:
Diffstat (limited to 'jenkins/create_jobs.groovy')
-rw-r--r--jenkins/create_jobs.groovy3
1 files changed, 2 insertions, 1 deletions
diff --git a/jenkins/create_jobs.groovy b/jenkins/create_jobs.groovy
index cd5bba6682..6d5bb95210 100644
--- a/jenkins/create_jobs.groovy
+++ b/jenkins/create_jobs.groovy
@@ -201,8 +201,9 @@ rm -rf examples excelant integrationtest main ooxml ooxml-schema scratchpad buil
# show which files are currently modified in the working copy
svn status || true
# make sure no changed module-class-files are lingering on
svn revert poi*/src/*/java9/module-info.* || true
+svn revert src/resources/ooxml-lite-report.* || true
# print out information about which exact version of java we are using
echo Java-Home: $JAVA_HOME
@@ -201,8 +201,9 @@ rm -rf examples excelant integrationtest main ooxml ooxml-schema scratchpad buil
# show which files are currently modified in the working copy
svn status || true
-# make sure no changed module-class-files are lingering on
+# make sure no changed module-class-files or ooxml-lite-report-files are lingering on
svn revert poi*/src/*/java9/module-info.* || true